﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using Infragistics.Controls.Schedules;

namespace XamGanttDemo
{
    public class XamGanttViewModel : INotifyPropertyChanged
    {
        private Project _project;
        public Project Project
        {
            get { return _project; }
            set
            {
                _project = value;
                NotifyPropertyChanged("Project");
            }
        }

        public XamGanttViewModel()
        {
            LoadDefaultProject();
        }

        private void LoadDefaultProject()
        {
            Project = new Project();

            var parent = new ProjectTask
            {
                TaskName = "Project Summary",
                Manual = false,
            };

            Project.RootTask.Tasks.Add(parent);

            parent.Tasks.Add(new ProjectTask
            {
                TaskName = "Create specification and requirements",
                Manual = false,
                Start = DateTime.Today.AddHours(8).ToUniversalTime(),
                ManualDuration = ProjectDuration.FromFormatUnits(4, ProjectDurationFormat.Days),
            });

            parent.Tasks.Add(new ProjectTask
            {
                TaskName = "Create a demo",
                Manual = true,
                Start = DateTime.Today.AddHours(8).ToUniversalTime(),
                Duration = TimeSpan.FromHours(16),
                Estimated = true,
            });

            parent.Tasks.Add(new ProjectTask
            {
                TaskName = "Implementation",
                Manual = true,
                Start = DateTime.Today.AddHours(8).ToUniversalTime(),
                DurationText = "A couple Of days",
            });

            parent.Tasks.Add(new ProjectTask
            {
                TaskName = "Testings",
                Manual = false,
                Active = false,
                Start = DateTime.Today.AddHours(8).ToUniversalTime(),
                Duration = TimeSpan.FromHours(12)
            });

            parent.Tasks.Add(new ProjectTask
            {
                TaskName = "0 day Milestone",
                Manual = false,
                Start = DateTime.Today.AddHours(8).ToUniversalTime(),
                Duration = TimeSpan.Zero
            });

            parent.Tasks.Add(new ProjectTask
            {
                TaskName = "2 day Milestone",
                Manual = false,
                Milestone = true,
                Start = DateTime.Today.AddHours(8).ToUniversalTime(),
                Duration = TimeSpan.FromHours(8 * 2)
            });
        }

        #region INotifyPropertyChanged

        public event PropertyChangedEventHandler PropertyChanged;
        protected void NotifyPropertyChanged(string propertyName)
        {
            var handler = PropertyChanged;
            if (handler != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }

        #endregion //INotifyPropertyChanged
    }
}
